(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('ngx-overflow-shadow', ['exports', '@angular/core'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-overflow-shadow'] = {}, global.ng.core));
}(this, (function (exports, core) { 'use strict';

    var NgxOverflowShadowDirective = /** @class */ (function () {
        function NgxOverflowShadowDirective(renderer, elementRef) {
            this.renderer = renderer;
            this.elementRef = elementRef;
            this.shadowStyle = '0 0 8px 1px rgba(0, 0, 0, 0.5)';
        }
        NgxOverflowShadowDirective.prototype.ngAfterViewInit = function () {
            var nativeElement = this.elementRef.nativeElement;
            this.observer = new IntersectionObserver(this.callback.bind(this), { root: nativeElement });
            this.createBottomPlaceholderDiv(nativeElement);
            this.createBottomShadowDiv(nativeElement);
        };
        NgxOverflowShadowDirective.prototype.ngOnDestroy = function () {
            this.observer.disconnect();
        };
        NgxOverflowShadowDirective.prototype.createBottomPlaceholderDiv = function (nativeElement) {
            var bottomPlaceholderDiv = this.renderer.createElement('div');
            this.renderer.appendChild(nativeElement, bottomPlaceholderDiv);
            this.observer.observe(bottomPlaceholderDiv);
        };
        NgxOverflowShadowDirective.prototype.createBottomShadowDiv = function (nativeElement) {
            var _this = this;
            this.bottomShadowDiv = this.renderer.createElement('div');
            Object.keys(NgxOverflowShadowDirective.DEFAULT_STYLE).forEach(function (prop) {
                _this.renderer.setStyle(_this.bottomShadowDiv, prop, NgxOverflowShadowDirective.DEFAULT_STYLE[prop]);
            });
            this.renderer.appendChild(nativeElement, this.bottomShadowDiv);
        };
        NgxOverflowShadowDirective.prototype.callback = function (entries) {
            var isIntersecting = entries.find(function (entry) { return entry.isIntersecting; });
            if (isIntersecting) {
                this.renderer.removeStyle(this.bottomShadowDiv, 'boxShadow');
            }
            else {
                this.renderer.setStyle(this.bottomShadowDiv, 'boxShadow', this.shadowStyle);
            }
        };
        return NgxOverflowShadowDirective;
    }());
    NgxOverflowShadowDirective.DEFAULT_STYLE = {
        position: 'sticky',
        bottom: 0
    };
    NgxOverflowShadowDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ngxOverflowShadow]'
                },] }
    ];
    NgxOverflowShadowDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef }
    ]; };
    NgxOverflowShadowDirective.propDecorators = {
        shadowStyle: [{ type: core.Input }]
    };

    var NgxOverflowShadowModule = /** @class */ (function () {
        function NgxOverflowShadowModule() {
        }
        return NgxOverflowShadowModule;
    }());
    NgxOverflowShadowModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [NgxOverflowShadowDirective],
                    exports: [NgxOverflowShadowDirective]
                },] }
    ];

    /*
     * Public API Surface of ngx-overflow-shadow
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxOverflowShadowDirective = NgxOverflowShadowDirective;
    exports.NgxOverflowShadowModule = NgxOverflowShadowModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-overflow-shadow.umd.js.map
