import { Directive, Renderer2, ElementRef, Input, NgModule } from '@angular/core';

class NgxOverflowShadowDirective {
    constructor(renderer, elementRef) {
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.shadowStyle = '0 0 8px 1px rgba(0, 0, 0, 0.5)';
    }
    ngAfterViewInit() {
        const { nativeElement } = this.elementRef;
        this.observer = new IntersectionObserver(this.callback.bind(this), { root: nativeElement });
        this.createBottomPlaceholderDiv(nativeElement);
        this.createBottomShadowDiv(nativeElement);
    }
    ngOnDestroy() {
        this.observer.disconnect();
    }
    createBottomPlaceholderDiv(nativeElement) {
        const bottomPlaceholderDiv = this.renderer.createElement('div');
        this.renderer.appendChild(nativeElement, bottomPlaceholderDiv);
        this.observer.observe(bottomPlaceholderDiv);
    }
    createBottomShadowDiv(nativeElement) {
        this.bottomShadowDiv = this.renderer.createElement('div');
        Object.keys(NgxOverflowShadowDirective.DEFAULT_STYLE).forEach((prop) => {
            this.renderer.setStyle(this.bottomShadowDiv, prop, NgxOverflowShadowDirective.DEFAULT_STYLE[prop]);
        });
        this.renderer.appendChild(nativeElement, this.bottomShadowDiv);
    }
    callback(entries) {
        const isIntersecting = entries.find((entry) => entry.isIntersecting);
        if (isIntersecting) {
            this.renderer.removeStyle(this.bottomShadowDiv, 'boxShadow');
        }
        else {
            this.renderer.setStyle(this.bottomShadowDiv, 'boxShadow', this.shadowStyle);
        }
    }
}
NgxOverflowShadowDirective.DEFAULT_STYLE = {
    position: 'sticky',
    bottom: 0
};
NgxOverflowShadowDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxOverflowShadow]'
            },] }
];
NgxOverflowShadowDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef }
];
NgxOverflowShadowDirective.propDecorators = {
    shadowStyle: [{ type: Input }]
};

class NgxOverflowShadowModule {
}
NgxOverflowShadowModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxOverflowShadowDirective],
                exports: [NgxOverflowShadowDirective]
            },] }
];

/*
 * Public API Surface of ngx-overflow-shadow
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxOverflowShadowDirective, NgxOverflowShadowModule };
//# sourceMappingURL=ngx-overflow-shadow.js.map
